@@ -25,7 +25,7 @@ use DateTime::Format::Strptime qw/strptime/;
 
 extends 'W3C::SOAP::Base';
 
-our $VERSION     = version->new('0.10');
+our $VERSION     = version->new('0.11');
 
 has xsd_ns => (
     is  => 'rw',
@@ -303,7 +303,7 @@ sub xsd_subtype {
         :                   $parent_type;
 
     my $subtype = $parent_type =~ /^xsd:\w/xms && Moose::Util::TypeConstraints::find_type_constraint($parent_type);
-    return $subtype if $subtype && !$args{list};
+    return $subtype if $subtype && !($args{list} || $args{simple_list});
 
     $subtype = subtype
         as $parent_type_name,
@@ -347,12 +347,21 @@ sub xsd_subtype {
             via { $_->textContent };
     }
 
+    if ($args{simple_list}) {
+        coerce $subtype =>
+            from "ArrayRef" =>
+            via { join ' ', @$_ };
+    }
     # Propogate coercion from Any via parent's type coercion.
     my $this_type = $subtype->parent;
-    if ($this_type->has_parent) {
+    if ($this_type->has_parent && ref $this_type->parent) {
         coerce $subtype
             => from 'Any'
-            => via { !defined $_ && $args{nillable} ? undef : $this_type->parent->coerce($_) };
+            => via {
+                !defined $_ && $args{nillable} ? undef
+                : $args{nillable}              ? Moose::Util::TypeConstraints::find_type_constraint($parent_type)->coerce($_)
+                :                                $this_type->parent->coerce($_)
+            };
     }
 
     return $subtype;
@@ -368,7 +377,7 @@ W3C::SOAP::XSD - The parent module for generated XSD modules.
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD version 0.10.
+This documentation refers to W3C::SOAP::XSD version 0.11.
 
 =head1 SYNOPSIS
 
