@@ -19,7 +19,7 @@ use W3C::SOAP::Utils qw/split_ns/;
 
 extends 'W3C::SOAP::XSD::Document::Type';
 
-our $VERSION     = version->new('0.10');
+our $VERSION     = version->new('0.11');
 
 has type => (
     is         => 'rw',
@@ -27,6 +27,12 @@ has type => (
     builder    => '_type',
     lazy       => 1,
 );
+has list => (
+    is         => 'rw',
+    isa        => 'Bool',
+    builder    => '_list',
+    lazy       => 1,
+);
 has enumeration => (
     is         => 'rw',
     isa        => 'ArrayRef[Str]',
@@ -66,10 +72,20 @@ sub _type {
     my ($self) = @_;
     my ($restriction) = $self->document->xpc->findnodes('xsd:restriction', $self->node);
 
-    return '' if !$restriction;
+    return $restriction->getAttribute('base') if $restriction;
+
+    ($restriction) = $self->document->xpc->findnodes('xsd:list/xsd:simpleType/xsd:restriction', $self->node);
+
     return $restriction->getAttribute('base');
 }
 
+sub _list {
+    my ($self) = @_;
+    my ($restriction) = $self->document->xpc->findnodes('xsd:list', $self->node);
+
+    return $restriction ? 1 : undef;
+}
+
 sub _enumeration {
     my ($self) = @_;
     my @nodes = $self->document->xpc->findnodes('xsd:restriction/xsd:enumeration', $self->node);
@@ -131,7 +147,7 @@ W3C::SOAP::XSD::Document::SimpleType - Represents simpleType elements of XSD doc
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Document::SimpleType version 0.10.
+This documentation refers to W3C::SOAP::XSD::Document::SimpleType version 0.11.
 
 
 =head1 SYNOPSIS
